#include <stdio.h>
#include <Cdef21364.h>
#include <def21364.h>
#include <signal.h>
#include <math.h>


//Function declarations

void InitSRU(); //-- Routes SPORT0 and SPORT1 signals to SRC0
void Sport0Init();
void Sport1Init();
void SRC0Init();
void ProbeOnDAI();

void InitTxBuffer();

void Sport0TxIsr(int dummy);
void Sport1RxIsr(int dummy);

int TxBuffer[360];
int RxBuffer[360];
int TxCnt = 0;
int RxCnt = 0;


void main(void)
{
	InitTxBuffer();
	ProbeOnDAI();//Probe SPORT0 and SPORT1 signals on DAI pins
	InitSRU();
	
	Sport0Init();//Initialize the SPORT0 for I2S mode	
	Sport1Init();//Initialize the SPORT1 for I2S mode
	
	SRC0Init();//Initialize SRC0 
	
	interrupts(SIG_P6,Sport0TxIsr);//set up sport0 interrupt
	interrupts(SIG_P3,Sport1RxIsr);//set up sport1 interrupt
	
	
	//Wait for SPORT interrupts
	while(1)
	{
	}
	
		
	
}


//Function Definitions --------------------------------------------------------------
//-----------------------------------------------------------------------------------

//Initialize SRC0 

void SRC0Init()
{
	*pSRCCTL0 = SRC0_SMODEIN0 | SRC0_SMODEOUT0 | SRC0_ENABLE ;
}


//-------------------------------------------------------
//-------------------------------------------------------

//Initialize SPORT0
void Sport0Init()
{
	*pDIV0 = 0x0018000e;
	*pSPCTL0 |= SPEN_A | SLEN24 | MSTR | OPMODE | SPTRAN;//SPORT0 configuration:
														//Internal clock and word select 
														//I2S mode
														//Transmitter
														//Word length 24
}
//-------------------------------------------------------
//-------------------------------------------------------

//Initialize SPORT1
void Sport1Init()
{
	*pDIV1 = 0x0090000e;
	*pSPCTL1 |= SPEN_A | MSTR | SLEN24 | OPMODE | DITFS;		//SPORT1 configuration:
														//Internal clock and word select 
														//I2S mode
														//Receiver
														//Word length 24
}
//-------------------------------------------------------
//-------------------------------------------------------


void Sport0TxIsr(int dummy)
{
	*pTXSP0A = TxBuffer[TxCnt % 360];
	TxCnt++;
}
//-------------------------------------------------------
//-------------------------------------------------------

void Sport1RxIsr(int dummy)
{
	
	RxBuffer[RxCnt % 360] = *pRXSP1A;
	RxCnt++;
}
//-------------------------------------------------------
//-------------------------------------------------------

//Initialize TxBuffer --  triangular wave
void InitTxBuffer()
{
	int i;
	int j = 180;
	for (i=0; i<=179; i++)
	{
		TxBuffer[i] = i+1;
	}
	
	for (i=180; i>=1; i--)
	{
		TxBuffer[j] = i;
		j++;
	}
}


